==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/RadioGroup.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { RadioGroupAlignment_$type } from "./RadioGroupAlignment";
/**
 * @hidden
 */
var RadioGroup = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadioGroup, _super);
    function RadioGroup() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(RadioGroup.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RadioGroup.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.b.n = this.d;
        },
        enumerable: false,
        configurable: true
    });
    RadioGroup.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(RadioGroup.prototype, "a", {
        get: function () {
            var ret_ = this.c.m("alignment");
            ret_ = enumGetBox(RadioGroupAlignment_$type, EnumUtil.getEnumValue(RadioGroupAlignment_$type, this.c.f(RadioGroupAlignment_$type, ret_)));
            return EnumUtil.getEnumValue(RadioGroupAlignment_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(RadioGroupAlignment_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.c.u("alignment", value_);
        },
        enumerable: false,
        configurable: true
    });
    RadioGroup.$t = markType(RadioGroup, 'RadioGroup', BaseElement.$);
    return RadioGroup;
}(BaseElement));
export { RadioGroup };

==> igniteui-react-18.6.1-beta.0.tgz: package/esm5/lib/RadioGroup.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { RadioGroupAlignment_$type } from "./RadioGroupAlignment";
/**
 * @hidden
 */
var RadioGroup = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadioGroup, _super);
    function RadioGroup() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(RadioGroup.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RadioGroup.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.b.o = this.d;
        },
        enumerable: false,
        configurable: true
    });
    RadioGroup.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(RadioGroup.prototype, "a", {
        get: function () {
            var ret_ = this.c.n("alignment");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(RadioGroupAlignment_$type, EnumUtil.getEnumValue(RadioGroupAlignment_$type, this.c.f(RadioGroupAlignment_$type, ret_)));
            return EnumUtil.getEnumValue(RadioGroupAlignment_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(RadioGroupAlignment_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.c.v("alignment", value_);
        },
        enumerable: false,
        configurable: true
    });
    RadioGroup.$t = markType(RadioGroup, 'RadioGroup', BaseElement.$);
    return RadioGroup;
}(BaseElement));
export { RadioGroup };
